#
# spec file for package scid
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           scid
Version:        4.6.2
Release:        lp150.5.17
Summary:        A chess database application
License:        GPL-2.0
Group:          Amusements/Games/Board/Chess
Url:            http://scid.sourceforge.net/
Source:         %{name}-%{version}.zip
Source1:        %{name}.png
Source2:        %{name}.desktop
Source3:        %{name}.6
# PATCH-FIX-UPSTREAM scid-Makefile.patch rpm@fthiessen.de -- https://sf.net/p/scid/patches/7/
Patch0:         %{name}-Makefile.patch
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  phalanx
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-devel
Requires:       phalanx
Requires:       python
Requires:       tcl
Requires:       tk
Recommends:     snack
Obsoletes:      scid-beta < %{version}
Provides:       scid-beta = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Scid can perform many different searches, such as for particular
players, a certain opening position, material searches, and pattern
searches such as isolated pawns. It is very fast, because it uses its
own efficient format, but it can convert games to and from PGN, the
standard format for chess game files.

Scid can use a chess engine such as Crafty to analyze games and also
has a "tree" mode where it automatically shows all moves played from
the current position, their opening codes, success rates, etc.

%prep
%setup -q -n %{name}-src
%patch0 -p1
dos2unix COPYING ChangeLog TODO
# Fake build date
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
sed -i "s:__DATE__:$DATE:g" src/tkscid.cpp

%build
# This is not autoconf
./configure \
    BINDIR=%{_bindir} \
    SHAREDIR=%{_datadir}/scid \
    OPTIMIZE="%{optflags} -fno-rtti -fno-exceptions"
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install_scid
# install sound files
mkdir -p %{buildroot}%{_datadir}/scid/sounds/
install -m 644  sounds/* %{buildroot}%{_datadir}/scid/sounds/
# install desktop file & icon
install -D -m 644 %{SOURCE1} %{buildroot}%{_datadir}/pixmaps/scid.png
install -D -m 644 %{SOURCE2} %{buildroot}%{_datadir}/applications/scid.desktop
%suse_update_desktop_file -i "scid" Game BoardGame
# install man page
install -D -m 644 %{SOURCE3} %{buildroot}%{_mandir}/man6/scid.6
# Workaround: Use phalanx version from openSUSE due to broken one in scid itself
ln -s %{_bindir}/phalanx %{buildroot}%{_bindir}/phalanx-scid
# fix permissions
find %{buildroot}%{_datadir}/%{name}/books/ -type f -exec chmod 0644 {} +
%fdupes %{buildroot}%{_datadir}

%post
#show a warning reminding the user to backup his databases
echo 'WARNING !!!'
echo "Scid 4.x uses a new database format."
echo "When opening an old database,"
echo "you will be asked to convert it to the new format."
echo "So if you are updating from scid 3.x _backup_ your old databases first!"

%files
%defattr(-,root,root)
%doc COPYING ChangeLog TODO
%{_datadir}/scid/
%{_datadir}/applications/scid.desktop
%{_datadir}/pixmaps/scid.png
%{_bindir}/*
%{_mandir}/man6/scid*

%changelog
* Wed Nov 25 2015 rpm@fthiessen.de
- Update to 4.6.2
- Replaced scid-4.5.2-Makefile.patch with new makefile patch:
  scid-Makefile.patch
- Removed unneeded patches scid-4.4-soundfolder.patch
  scid-4.4-fix_eco_browser_translation.patch
  scid-4.4-rename_engines.patch
  scid-4.4-fix_fsf_address.patch
* Wed Jun  4 2014 stefan@fam-elser.de
- Rewritten Makefile patch for version 4.5.2
- updated to version 4.5.2
  * Open multiple gamelist windows
  * New (faster) position search (used only by gamelist windows at the moment)
  * Save game to a different database from the current one
  * Search in a different database from the current one
  * Faster database opening
  * Select bases to be automatically loaded ad startup (right click in database switcher -> "load at startup")
  * Easy customization of piece sets and boards textures (change images inside the new "img" directory)
  * Windows binaries use tcl/tk 8.6
  * Several bugfixes
* Thu Aug 29 2013 stefan@fam-elser.de
- updated to version 4.4
  * Added two buttons (prev/next) to navigate the history of viewed games
  * Gamelist can sort games; thanks to "SortCache" by Gerd Lorscheid
  * New "Best games window"
  * Tree Window can show statistics for filtered games
  * New option "Include arrow with move highlight", thanks to Mike Curtis
  * swedish translation update (thanks to Hans Eriksson)
  * german translation update
  * finnish translation update (thanks to Timo Pirinen)
- added a static link to spec file to get rid of the phalanx engine init errors (workaround)
- modified the make install part to only install scid without built-in engines
- added patch to fix old FSF address
* Tue May 29 2012 joop.boonen@opensuse.org
- ./configure needs to be used instead of configure macro as
  - -disable-dependency-tracking breaks configure
* Thu Apr 22 2010 packman@links2linux.de
- added patch to fix ECO browser if language is not set to english
  * If scid is run with i.e.german language selected the ECO browser displayed some moves
    incorrectly, for example instead of moving a bishop (german = "Läufer")
    a pawn (german = "Bauer") was moved.
    Fix by Hubert Mantel - mantel@suse.de
* Tue Mar  9 2010 packman@links2linux.de
- changed installation location for included extra engines phalanx and togaII from /usr/share/scid/engines/ to /usr/bin
- renamed engine togaII to togaII-1.2.1a-scid to avoid potential conflicts with already installed togaII-engines
- removed obsolete rpmlintrc-file
* Wed Jan 20 2010 axel@links2linux.de
- updated to version 4.2.2
  * Training -> Find best move : make it more user friendly :
    The next moves are automaticaly hidden in PGN window and in game info window
    Added buttons above the board to show solution, go to next / previous exercise
    Leave the training mode by unchecking the menu entry
  * updated swedish translation (thanks to Hans Eriksson)
  * updated spanish translation (thanks to Pedro Reina)
  * Scid Pocket : added Stockfish 1.6.2 ported to ARM (Windows Mobile)
  * FIDE changed the number of rating list per year. Add code to handle this properly.
    Maximum year for ratings added by spellchecker is _2010_. (Thanks to Joost 't Hart)
  * Searching for !me (own games) was broken
  * Xfcc passwords with XML entities were not handled correctly
- fixed building with RPM_OPT_FLAGS
* Wed Jan  6 2010 AxelKoellhofer@web.de
- updated to version 4.1
- removed obsolete patch to fix comments on last move (fixed upstream)
* Thu Sep 17 2009 AxelKoellhofer@web.de
- added upstream fix for entering comments on last move
* Wed Sep  2 2009 AxelKoellhofer@web.de
- updated to 4.0 (see /usr/share/doc/packages/scid/ChangeLog for all the new features)
- added desktop file and icon
- enabled sound
- added Obsoletes/Provides/Recommends
- patches refreshed
- added python to Requires
- changed License tag to GPL v2 (the file COPYING contains GPL v2 and no other version)
* Fri Aug 21 2009 AxelKoellhofer@web.de
- updated to 3.7.3
- patches refreshed
* Fri Nov 28 2008 dominique-obs@leuenberger.net
- Use fixed version to detect Tk on openSUSE 11.0
* Thu Feb  7 2008 detlef.steuer@gmx.de
- updated for 3.6.22
* Mon Jan 14 2008 detlef.steuer@gmx.de
- updated for 3.6.21
* Sat Nov 24 2007 detlef.steuer@gmx.de
- first try with pgeorges scid
* Sat Oct 28 2006 meissner@suse.de
- use RPM_OPT_FLAGS
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Mar  3 2004 mcihar@suse.cz
- update to 3.6.1
* Mon Feb 23 2004 mcihar@suse.cz
- update to 3.5
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Sep 22 2003 ro@suse.de
- do not provuide phalanx
* Mon Jul 28 2003 ro@suse.de
- added tk-devel to neededforbuild
* Tue May 27 2003 mcihar@suse.cz
- move binaries to /usr/bin
* Thu Feb  6 2003 mcihar@suse.cz
- updated to 3.4
  * Scid now has its own built-in analysis engine called Scidlet;
    you can still use other WinBoard-compatible engines for
    analysis in Scid, of course.
  * New Player Finder window.
  * More improvements to the Tablebase window.
  * Moves on the main window chessboard are now animated.
  * Lots of small user interface improvements.
  * Added support for entering null (empty) moves in games.
* Sun Aug 18 2002 ro@suse.de
- add "-DUSE_NON_CONST" to cflags for new tcl
* Fri Jul 12 2002 max@suse.de
- Patching Makefile.conf and using configure instead of
  patching Makefile, so that the Tcl/Tk version can be
  detected at build time.
* Thu Jun 13 2002 mcihar@suse.cz
- updated to 3.3:
  * New "Piece Tracker" tool, new "Filter Graph" window
  * Maintenance window: new "Strip PGN tags" operation that finds
    extra PGN tags and allows the user to remove all instances of
    a particular unwanted tag.
  * Added "Load Random Game" menu command in the Game menu.
  * Extended search capabilities
  * Improved reading of annotations in PGN.
  * Removed limitation of game to 128 moves.
  * Improved the look of piece images in the chessboard.
* Wed Apr 24 2002 pmladek@suse.cz
- used macro %%{_lib} to fix for lib64
* Tue Jan 29 2002 pmladek@suse.cz
- updated to version 3.1
* Wed Dec  5 2001 pmladek@suse.cz
- updated on version 3.0:
  * new database format
  * new "Bookmarks" feature
  * new "Tip of the day" window
  * most window locations and sizes are now saved in the options file when "Save Options" is selected.
  * tree window: New "Best games" window
  * 12 new user-settable "flags" for marking games with various chess characteristics.
- added tk to Requires
- fixed to load spelling.ssp
* Mon Jun 25 2001 pblaha@suse.cz
- update on 2.5
* Wed May 30 2001 pblaha@suse.cz
- update on 2.4
- rewrite URL
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Tue Jan 16 2001 pblaha@suse.cz
- create this package
